import webpack from 'webpack';
import path from 'path';

const NODE_ENV = process.env.NODE_ENV = process.env.NODE_ENV || 'development';
const node_env = NODE_ENV.toLowerCase();

// path helpers
const root = path.resolve(__dirname, '../../../');
const resolve = function (localPath) {
  return path.resolve(root, localPath);
};

export default {
  entry : {
    lib : [
      resolve('src/harness.jsx')
    ]
  },
  output : {
    path : resolve('dist'),
    filename : 'react-toast.js'
  },
  target  : 'web',
  plugins : [
    new webpack.DefinePlugin({
      'process.env' : {
        'NODE_ENV' : JSON.stringify(node_env)
      },
      '__PROD__' : node_env === 'production',
      '__DEV__'  : node_env === 'development'
    }),
    new webpack.optimize.DedupePlugin()
  ],
  resolve : {
    extensions : ['', '.js', '.jsx']
  },
  module : {
    preLoaders : [{
      test : /\.js?$/,
      exclude : /node_modules/,
      loader : 'jshint'
    }, {
      test : /\.jsx?$/,
      exclude : /node_modules/,
      loader : 'jsxhint'
    }],
    loaders : [{
      include : resolve('src'),
      test    : [/\.(js|jsx)?$/],
      loaders : ['babel']
    }]
  },
  jshint : {
    emitErrors : false,
    failOnHint : false,
    reporter   : require('jshint-loader-stylish')()
  }
};
