import { EventEmitter } from 'events';
import ToastDispatcher from './dispatcher';
import {
  REACT_TOAST_CREATE,
  REACT_TOAST_DESTROY
} from './constants';

const CHANGE_EVENT = 'REACT_TOAST_CHANGE_EVENT';
const uniqueId = (function (seed) {
  return () => seed++;
})(0);

var _messages = [];

class ReactToastStore extends EventEmitter {
  constructor () {
    super();

    const self = this;
    ToastDispatcher.register(function (action) {
      const { actionType, payload } = action;

      switch (actionType) {
        case REACT_TOAST_CREATE:
          self.create(payload.type, payload.message);
          self.emitChange();
          break;
        case REACT_TOAST_DESTROY:
          self.destroy(payload.id);
          self.emitChange();
          break;
      }
    });
  }

  getAll () {
    return _messages;
  }

  create (type, message) {
    const toastMessage = {
      id   : uniqueId(),
      type, message
    };

    _messages.push(toastMessage);
  }

  destroy (id) {
    for (let i=0, len=_messages.length; i < len; i++) {
      if (_messages[i].id === id) {
        _messages.splice(i, 1);
        break;
      }
    }
  }

  emitChange () {
    this.emit(CHANGE_EVENT);
  }

  addChangeListener (callback) {
    this.on(CHANGE_EVENT, callback);
  }

  removeChangeListener (callback) {
    this.removeListener(CHANGE_EVENT, callback);
  }
}

export default new ReactToastStore();
